@@ -4,7 +4,7 @@ import os
 from pathlib import Path
 from .cute_python import snek
 
-__version__ = '0.1.8'
+__version__ = '0.1.9'
 
 DSL_CACHE = os.environ.get("DSL_CACHE")
 
@@ -12,7 +12,9 @@ def pritty_print(msg):
     print('\n','#'*len(msg),'\n',msg,'\n','#'*len(msg))
 
 def import_local(g):
-    PROJECT_APP = Path(g['__file__']).resolve(strict=True).parent.name
+    CWD = Path(os.getcwd())
+    PWD = Path(g['__file__']).resolve(strict=True).parent
+    PROJECT_APP = ".".join(PWD.relative_to(CWD).parts)
     try:
         msg = "Django local settings applied"
         settings_local = importlib.import_module(".settings_local", PROJECT_APP)
@@ -23,7 +25,7 @@ def import_local(g):
         settings_local.patch_globals(g)
     except ImportError:
         msg = "Use `settings_local.py` in the project app to override global settings"
-    except AttributeError:
+    except (AttributeError, TypeError):
         msg = "For global settings mutation, see format of settings_local.py `dsl -f`"
     finally:
         if not DSL_CACHE:
